@@ -218,16 +218,23 @@ using "hstore" extension to be able to browse sessions.
 
 L<http://lemonldap-ng.org>, L<Apache::Session::Postgres>
 
-=head1 AUTHOR
-
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>
-
 =head1 COPYRIGHT AND LICENSE
 
 =encoding utf8
 
-Copyright (C) 2009-2017 by Xavier Guimard
-              2013-2017 by Clément Oudot
+=over
+
+=item 2009-2023 by Xavier Guimard
+
+=item 2013-2023 by Clément Oudot
+
+=item 2019-2023 by Maxime Besson
+
+=item 2013-2023 by Worteks
+
+=item 2023 by Linagora
+
+=back
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.1 or,
